-- this is an incredibly simple plugin that just creates a shell command "/unequip" and then
-- listens for "/unequip %1" where %1 is the name of the slot to unequip
-- user can then put "/unequip SecondaryWeapon" in a quickslot and it will unequip that item

import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";

language=1;
locale = "en";
if Turbine.Shell.IsCommand("hilfe") then
	locale = "de";
	language=3;
elseif Turbine.Shell.IsCommand("aide") then
	locale = "fr";
	language=2;
end

string.split=function(str,separator)
	local tmpArray={};
	local tmpElem;
	str=tostring(str);
	if string.find("^$()%.[]*+-?",separator,1,true)~=nil then separator="%"..separator end
	for tmpElem in string.gmatch(str,"[^"..separator.."]*") do
		table.insert(tmpArray,tmpElem);
	end
	local tmpIndex=1;
	while tmpIndex<=#tmpArray do
		if tmpIndex==#tmpArray and tmpArray[tmpIndex]=="" then
			table.remove(tmpArray,tmpIndex);
		else
			if tmpArray[tmpIndex]=="" and tmpArray[tmpIndex+1]~="" then
				table.remove(tmpArray,tmpIndex);
			else
				tmpIndex=tmpIndex+1;
			end
		end
	end
	return tmpArray;
end

string.ltrim=function(str)
	return (string.gsub(str, "^%s*(.-)", "%1"))
end
string.rtrim=function(str)
	return (string.gsub(str, "^(.-)%s*$", "%1"))
end
string.trim=function(str)
	return (string.gsub(str, "^%s*(.-)%s*$", "%1"))
end

unequipperControl=Turbine.UI.Control()
unequipperControl.loaded=false
unequipperControl.Update=function()
	if Plugins["Unequipper"] ~= nil and (not unequipperControl.loaded) then
		unequipperControl.loaded=true;
		unequipperControl:SetWantsUpdates(false);
		Plugins["Unequipper"].Unload = function(self,sender,args)
			Turbine.Shell.RemoveCommand(unequipperControl.shellCmd)
		end
		Turbine.Shell.WriteLine("Unequipper "..Plugins["Unequipper"]:GetVersion().." loaded");
	end
end

unequipperControl.shellCmd=Turbine.ShellCommand();
local numberOfCommandsRegistered = Turbine.Shell.AddCommand("Unequip",unequipperControl.shellCmd);

unequipperControl.shellCmd.Execute = function(sender, cmd, args)
	local pos1=string.find(args," ",0,true);
	local slot;
	if pos1~=nil and pos1>0 then
		slot=string.lower(string.sub(args,1,pos1-1));
	else
		slot=string.lower(args);
	end

	unequipperControl.slot=0;
	if (slot=="back") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Back;
	elseif (slot=="boots") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Boots;
	elseif (slot=="bracelet1") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Bracelet1;
	elseif (slot=="bracelet2") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Bracelet2;
	elseif (slot=="chest") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Chest;
	elseif (slot=="class") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Class;
	elseif (slot=="crafttool") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.CraftTool;
	elseif (slot=="earring1") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Earring1;
	elseif (slot=="earring2") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Earring2;
	elseif (slot=="gloves") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Gloves;
	elseif (slot=="head") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Head;
	elseif (slot=="instrument") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Instrument;
	elseif (slot=="legs") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Legs;
	elseif (slot=="necklace") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Necklace;
	elseif (slot=="pocket") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Pocket;
	elseif (slot=="primaryweapon") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.PrimaryWeapon;
	elseif (slot=="rangedweapon") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.RangedWeapon;
	elseif (slot=="ring1") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Ring1;
	elseif (slot=="ring2") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Ring2;
	elseif (slot=="secondaryweapon") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.SecondaryWeapon;
	elseif (slot=="shield") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Shield;
	elseif (slot=="shoulder") then
		unequipperControl.slot=Turbine.Gameplay.Equipment.Shoulder;
	else
		Turbine.Shell.WriteLine("usage:");
		Turbine.Shell.WriteLine("  /Unequip %1");
		Turbine.Shell.WriteLine("       Unequipps the item in slot %1. The valid slot names are:");
		Turbine.Shell.WriteLine("       Back, Boots, Bracelet1, Bracelet2, Chest, Class, CraftTool, Earring1, Earring2, Gloves, Head, Instrument, Legs, Necklace, Pocket, PrimaryWeapon, RangedWeapon, Ring1, Ring2, SecondaryWeapon, Shield, Shoulder");
	end
	if unequipperControl.slot~=0 then
		-- find an empty bag slot
		local bagSlot=-1;
		local index=0;
		local lp=Turbine.Gameplay.LocalPlayer:GetInstance();
		local bags=lp:GetBackpack();
		local equippedItems=lp:GetEquipment();
		local item=equippedItems:GetItem(unequipperControl.slot);

		for index=1, bags:GetSize() do
			if bags:GetItem(index)==nil then
				bagSlot=index;
				break;
			end
		end
		if bagSlot==-1 then
			Turbine.Shell.WriteLine("No empty slot found. Item not unequipped.");
		else
			if item~=nil then
				bags:PerformItemDrop(item, bagSlot, false);
			end
		end
	end
end


unequipperControl.shellCmd.GetHelp = function(sender, cmd)
	return("usage:\n  /Unequip %1\n       Unequipps the item in slot %1. The valid slot names are:\n  Back, Boots, Bracelet1, Bracelet2, Chest, Class, CraftTool, Earring1, Earring2, Gloves, Head, Instrument, Legs, Necklace, Pocket, PrimaryWeapon, RangedWeapon, Ring1, Ring2, SecondaryWeapon, Shield, Shoulder");
end

unequipperControl.shellCmd.GetShortHelp = function(sender, cmd)
	return("Valet - usage: /Unequip %1");
end

unequipperControl:SetWantsUpdates(true);
